@@ -31,14 +31,18 @@
 #endif
 #include <math.h>
 #include <stdlib.h>
+#include <libpq/libpq-fs.h>
 #include "statement.h"
 #include "qresult.h"
 #include "bind.h"
 #include "pgtypes.h"
-#include "lobj.h"
 #include "connection.h"
 #include "pgapifunc.h"
 
+#if defined(UNICODE_SUPPORT) && defined(WIN32)
+#define	WIN_UNICODE_SUPPORT
+#endif
+
 #ifdef	__CYGWIN__
 #  define TIMEZONE_GLOBAL _timezone
 #elif	defined(WIN32) || defined(HAVE_INT_TIMEZONE)
@@ -408,11 +412,13 @@ copy_and_convert_field(StatementClass *stmt, Int4 field_type, void *value, Int2
 	char		midtemp[2][32];
 	int			mtemp_cnt = 0;
 	GetDataClass *pgdc;
+#ifdef	UNICODE_SUPPORT
 	BOOL	wchanged =   FALSE;
-#ifdef	WIN32
+#endif /* UNICODE_SUPPORT */
+#ifdef	WIN_UNICODE_SUPPORT
 	SQLWCHAR	*allocbuf = NULL;
 	Int4		wstrlen;	
-#endif /* WIN32 */
+#endif /* WIN_UNICODE_SUPPORT */
 
 	if (stmt->current_col >= 0)
 	{
@@ -472,7 +478,6 @@ copy_and_convert_field(StatementClass *stmt, Int4 field_type, void *value, Int2
 	std_time.y = tim->tm_year + 1900;
 
 	mylog("copy_and_convert: field_type = %d, fctype = %d, value = '%s', cbValueMax=%d\n", field_type, fCType, (value == NULL) ? "<NULL>" : value, cbValueMax);
-
 	if (!value)
 	{
 		/*
@@ -687,7 +692,11 @@ inolog("2stime fr=%d\n", std_time.fr);
 		mylog("copy_and_convert, SQL_C_DEFAULT: fCType = %d\n", fCType);
 	}
 
+#ifdef	UNICODE_SUPPORT
 	if (fCType == SQL_C_CHAR || fCType == SQL_C_WCHAR
+#else
+	if (fCType == SQL_C_CHAR
+#endif /* UNICODE_SUPPORT */
 	    || fCType == INTERNAL_ASIS_TYPE)
 	{
 		/* Special character formatting as required */
@@ -756,7 +765,7 @@ inolog("2stime fr=%d\n", std_time.fr);
 				if (pgdc->data_left < 0)
 				{
 					BOOL lf_conv = conn->connInfo.lf_conversion;
-
+#ifdef	UNICODE_SUPPORT
 					if (fCType == SQL_C_WCHAR)
 					{
 						len = utf8_to_ucs2_lf(neut_str, -1, lf_conv, NULL, 0);
@@ -764,7 +773,7 @@ inolog("2stime fr=%d\n", std_time.fr);
 						wchanged = changed = TRUE;
 					}
 					else
-
+#endif /* UNICODE_SUPPORT */
 					if (PG_TYPE_BYTEA == field_type)
 					{
 						len = convert_from_pgbinary(neut_str, NULL, 0);
@@ -772,7 +781,7 @@ inolog("2stime fr=%d\n", std_time.fr);
 						changed = TRUE;
 					}
 					else
-#ifdef	WIN32
+#ifdef	WIN_UNICODE_SUPPORT
 					if (fCType == SQL_C_CHAR)
 					{
 						wstrlen = utf8_to_ucs2_lf(neut_str, -1, lf_conv, NULL, 0);
@@ -782,17 +791,17 @@ inolog("2stime fr=%d\n", std_time.fr);
 						changed = TRUE;
 					}
 					else
-#endif /* WIN32 */
+#endif /* WIN_UNICODE_SUPPORT */
 						/* convert linefeeds to carriage-return/linefeed */
 						len = convert_linefeeds(neut_str, NULL, 0, lf_conv, &changed);
 					if (cbValueMax == 0)		/* just returns length
 												 * info */
 					{
 						result = COPY_RESULT_TRUNCATED;
-#ifdef	WIN32
+#ifdef	WIN_UNICODE_SUPPORT
 						if (allocbuf)
 							free(allocbuf);
-#endif /* WIN32 */
+#endif /* WIN_UNICODE_SUPPORT */
 						break;
 					}
 					if (!pgdc->ttlbuf)
@@ -804,13 +813,13 @@ inolog("2stime fr=%d\n", std_time.fr);
 							pgdc->ttlbuf = realloc(pgdc->ttlbuf, len + 1);
 							pgdc->ttlbuflen = len + 1;
 						}
-
+#ifdef	UNICODE_SUPPORT
 						if (fCType == SQL_C_WCHAR)
 						{
 							utf8_to_ucs2_lf(neut_str, -1, lf_conv, (SQLWCHAR *) pgdc->ttlbuf, len / WCLEN);
 						}
 						else
-
+#endif /* UNICODE_SUPPORT */
 						if (PG_TYPE_BYTEA == field_type)
 						{
 							len = convert_from_pgbinary(neut_str, pgdc->ttlbuf, pgdc->ttlbuflen);
@@ -818,7 +827,7 @@ inolog("2stime fr=%d\n", std_time.fr);
 							len *= 2; 
 						}
 						else
-#ifdef	WIN32
+#ifdef	WIN_UNICODE_SUPPORT
 						if (fCType == SQL_C_CHAR)
 						{
 							len = WideCharToMultiByte(CP_ACP, 0, allocbuf, wstrlen, pgdc->ttlbuf, pgdc->ttlbuflen, NULL, NULL);
@@ -826,7 +835,7 @@ inolog("2stime fr=%d\n", std_time.fr);
 							allocbuf = NULL;
 						}
 						else
-#endif /* WIN32 */
+#endif /* WIN_UNICODE_SUPPORT */
 							convert_linefeeds(neut_str, pgdc->ttlbuf, pgdc->ttlbuflen, lf_conv, &changed);
 						ptr = pgdc->ttlbuf;
 						pgdc->ttlbufused = len;
@@ -865,12 +874,13 @@ inolog("2stime fr=%d\n", std_time.fr);
 					BOOL	already_copied = FALSE;
 
 					copy_len = (len >= cbValueMax) ? cbValueMax - 1 : len;
-
+#ifdef	UNICODE_SUPPORT
 					if (fCType == SQL_C_WCHAR)
 					{
 						copy_len /= WCLEN;
 						copy_len *= WCLEN;
 					}
+#endif /* UNICODE_SUPPORT */
 #ifdef HAVE_LOCALE_H
 					switch (field_type)
 					{
@@ -905,11 +915,11 @@ inolog("2stime fr=%d\n", std_time.fr);
 						/* Copy the data */
 						memcpy(rgbValueBindRow, ptr, copy_len);
 						/* Add null terminator */
-
+#ifdef	UNICODE_SUPPORT
 						if (fCType == SQL_C_WCHAR)
 							memset(rgbValueBindRow + copy_len, 0, WCLEN);
 						else
-
+#endif /* UNICODE_SUPPORT */
 						rgbValueBindRow[copy_len] = '\0';
 					}
 					/* Adjust data_left for next time */
@@ -936,24 +946,28 @@ inolog("2stime fr=%d\n", std_time.fr);
 				mylog("    SQL_C_CHAR, default: len = %d, cbValueMax = %d, rgbValueBindRow = '%s'\n", len, cbValueMax, rgbValueBindRow);
 				break;
 		}
-
+#ifdef	UNICODE_SUPPORT
 		if (SQL_C_WCHAR == fCType && ! wchanged)
 		{
-			if (cbValueMax > (SDWORD) (WCLEN * len))
+			if (cbValueMax > (SDWORD) (WCLEN * (len + 1)))
 			{
 				char *str = strdup(rgbValueBindRow);
 				UInt4	ucount = utf8_to_ucs2(str, len, (SQLWCHAR *) rgbValueBindRow, cbValueMax / WCLEN);
 				if (cbValueMax < (SDWORD) (WCLEN * ucount))
 					result = COPY_RESULT_TRUNCATED;
-				len = ucount * WCLEN;
 				free(str); 
 			}
 			else
 			{
-				len *= WCLEN;
-				result = COPY_RESULT_TRUNCATED;
+                if ((SDWORD) (len + WCLEN) <= cbValueMax)
+                {
+                    result = COPY_OK;
+                }
+                else
+                    result = COPY_RESULT_TRUNCATED; 
 			}
 		}
+#endif /* UNICODE_SUPPORT */
 
 	}
 	else
@@ -1573,7 +1587,7 @@ do { \
 	while (qp->statement[qp->opos] != '\0' && qp->statement[qp->opos] != ch) \
 	{ \
 	    buf[c++] = qp->statement[qp->opos++]; \
-		if (c >= maxsize) \
+		if (c >= maxsize - 1) \
 			break; \
 	} \
 	if (qp->statement[qp->opos] == '\0') \
@@ -1837,7 +1851,7 @@ Prepare_and_convert(StatementClass *stmt, QueryParse *qp, QueryBuild *qb)
 
 		new_statement = qb->query_statement;
 		qb->flags = FLGB_BUILDING_PREPARE_STATEMENT;
-		sprintf(new_statement, "PREPARE \"_PLAN%0x\"", stmt);
+		sprintf(new_statement, "PREPARE \"_PLAN%p\"", stmt);
 		qb->npos = strlen(new_statement);
 		if (SQL_SUCCESS != PGAPI_NumParams(stmt, &marker_count))
 		{
@@ -1873,7 +1887,7 @@ Prepare_and_convert(StatementClass *stmt, QueryParse *qp, QueryBuild *qb)
 		CVT_APPEND_CHAR(qb, ';');
 		/* build the execute statement */
 		exe_statement = malloc(30 + 2 * marker_count);
-		sprintf(exe_statement, "EXECUTE \"_PLAN%0x\"", stmt);
+		sprintf(exe_statement, "EXECUTE \"_PLAN%p\"", stmt);
 		if (marker_count > 0)
 		{
 			elen = strlen(exe_statement);
@@ -2357,7 +2371,7 @@ ResolveNumericParam(const SQL_NUMERIC_STRUCT *ns, char *chrform)
 			o2val = ival % div;
 			if (0 == ns->sign)
 				o1val *= -1;
-			sprintf(chrform, "%d.%0.*d", o1val, ns->scale, o2val);
+			sprintf(chrform, "%d.%.*d", o1val, ns->scale, o2val);
 		}
 		return TRUE;
 	}
@@ -2615,7 +2629,7 @@ ResolveOneParam(QueryBuild *qb)
 			buf = buffer;
 			break;
 		case SQL_C_CHAR:
-#ifdef	WIN32
+#ifdef	WIN_UNICODE_SUPPORT
 			switch (param_sqltype)
 			{
 				case SQL_WCHAR:
@@ -2635,15 +2649,17 @@ ResolveOneParam(QueryBuild *qb)
 			}
 #else
 			buf = buffer;
-#endif /* WIN32 */
+#endif /* WIN_UNICODE_SUPPORT */
 			break;
 
+#ifdef	UNICODE_SUPPORT
 		case SQL_C_WCHAR:
             if (SQL_NTS == used)
                 used = WCLEN * wcslen((SQLWCHAR *) buffer);
 			buf = allocbuf = ucs2_to_utf8((SQLWCHAR *) buffer, used / WCLEN, (UInt4 *) &used, FALSE);
 			used *= WCLEN;
 			break;
+#endif /* UNICODE_SUPPORT */
 
 		case SQL_C_DOUBLE:
 			sprintf(param_string, "%.15g",
@@ -2657,8 +2673,8 @@ ResolveOneParam(QueryBuild *qb)
 
 		case SQL_C_SLONG:
 		case SQL_C_LONG:
-			sprintf(param_string, "%ld",
-					*((SDWORD *) buffer));
+			sprintf(param_string, "%d",
+					(int) *((SDWORD *) buffer));
 			break;
 
 #ifdef ODBCINT64
@@ -2686,8 +2702,8 @@ ResolveOneParam(QueryBuild *qb)
 			break;
 
 		case SQL_C_ULONG:
-			sprintf(param_string, "%lu",
-					*((UDWORD *) buffer));
+			sprintf(param_string, "%u",
+					(unsigned int) *((UDWORD *) buffer));
 			break;
 
 		case SQL_C_USHORT:
@@ -2771,9 +2787,11 @@ ResolveOneParam(QueryBuild *qb)
 		case SQL_CHAR:
 		case SQL_VARCHAR:
 		case SQL_LONGVARCHAR:
+#ifdef	UNICODE_SUPPORT
 		case SQL_WCHAR:
 		case SQL_WVARCHAR:
 		case SQL_WLONGVARCHAR:
+#endif /* UNICODE_SUPPORT */
 
 			CVT_APPEND_CHAR(qb, '\'');	/* Open Quote */
 
@@ -2911,7 +2929,7 @@ ResolveOneParam(QueryBuild *qb)
 				}
 
 				/* store the oid */
-				lobj_oid = lo_creat(conn, INV_READ | INV_WRITE);
+				lobj_oid = lo_creat(conn->pgconn, INV_READ | INV_WRITE);
 				if (lobj_oid == 0)
 				{
 					qb->errornumber = STMT_EXEC_ERROR;
@@ -2920,17 +2938,17 @@ ResolveOneParam(QueryBuild *qb)
 				}
 
 				/* store the fd */
-				lobj_fd = lo_open(conn, lobj_oid, INV_WRITE);
+				lobj_fd = lo_open(conn->pgconn, lobj_oid, INV_WRITE);
+
 				if (lobj_fd < 0)
 				{
 					qb->errornumber = STMT_EXEC_ERROR;
 					qb->errormsg = "Couldnt open (in-line) large object for writing.";
 					return SQL_ERROR;
 				}
-
-				retval = lo_write(conn, lobj_fd, buffer, used);
-
-				lo_close(conn, lobj_fd);
+		
+				retval = lo_write(conn->pgconn, lobj_fd, buffer, used);
+				lo_close(conn->pgconn, lobj_fd);
 
 				/* commit transaction if needed */
 				if (!ci->drivers.use_declarefetch && CC_is_in_autocommit(conn))
@@ -3891,7 +3909,8 @@ convert_lo(StatementClass *stmt, const void *value, Int2 fCType, PTR rgbValue,
 		}
 
 		oid = ATOI32U(value);
-		stmt->lobj_fd = lo_open(conn, oid, INV_READ);
+		stmt->lobj_fd = lo_open(conn->pgconn, oid, INV_READ);
+
 		if (stmt->lobj_fd < 0)
 		{
 			SC_set_error(stmt, STMT_EXEC_ERROR, "Couldnt open large object for reading.");
@@ -3899,15 +3918,17 @@ convert_lo(StatementClass *stmt, const void *value, Int2 fCType, PTR rgbValue,
 		}
 
 		/* Get the size */
-		retval = lo_lseek(conn, stmt->lobj_fd, 0L, SEEK_END);
+		retval = lo_lseek(conn->pgconn, stmt->lobj_fd, 0L, SEEK_END);
+
 		if (retval >= 0)
 		{
-			left = lo_tell(conn, stmt->lobj_fd);
+			left = lo_tell(conn->pgconn, stmt->lobj_fd);
+
 			if (gdata)
 				gdata->data_left = left;
 
 			/* return to beginning */
-			lo_lseek(conn, stmt->lobj_fd, 0L, SEEK_SET);
+			lo_lseek(conn->pgconn, stmt->lobj_fd, 0L, SEEK_SET);
 		}
 	}
 	mylog("lo data left = %d\n", left);
@@ -3921,10 +3942,11 @@ convert_lo(StatementClass *stmt, const void *value, Int2 fCType, PTR rgbValue,
 		return COPY_GENERAL_ERROR;
 	}
 
-	retval = lo_read(conn, stmt->lobj_fd, (char *) rgbValue, factor > 1 ? (cbValueMax - 1) / factor : cbValueMax);
+	retval = lo_read(conn->pgconn, stmt->lobj_fd, (char *) rgbValue, factor > 1 ? (cbValueMax - 1) / factor : cbValueMax);
+
 	if (retval < 0)
 	{
-		lo_close(conn, stmt->lobj_fd);
+		lo_close(conn->pgconn, stmt->lobj_fd);
 
 		/* commit transaction if needed */
 		if (!ci->drivers.use_declarefetch && CC_is_in_autocommit(conn))
@@ -3957,7 +3979,7 @@ convert_lo(StatementClass *stmt, const void *value, Int2 fCType, PTR rgbValue,
 
 	if (!gdata || gdata->data_left == 0)
 	{
-		lo_close(conn, stmt->lobj_fd);
+		lo_close(conn->pgconn, stmt->lobj_fd);
 
 		/* commit transaction if needed */
 		if (!ci->drivers.use_declarefetch && CC_is_in_autocommit(conn))
