@@ -16,15 +16,11 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-
 #include "connection.h"
 
 #ifndef WIN32
 #include <sys/types.h>
-#include <sys/socket.h>
 #define NEAR
-#else
-#include <winsock.h>
 #endif
 
 #include <string.h>
@@ -261,14 +257,19 @@ dialog:
 		 */
 		strncpy_null(szConnStrOut, connStrOut, cbConnStrOutMax);
 
-		if (len >= cbConnStrOutMax)
+		if (cbConnStrOutMax == 0)
+			szConnStrOut = NULL;	
+		else
 		{
-			int			clen;
+			if (len >= cbConnStrOutMax)
+			{
+				int			clen;
 
-			for (clen = strlen(szConnStrOut) - 1; clen >= 0 && szConnStrOut[clen] != ';'; clen--)
-				szConnStrOut[clen] = '\0';
-			result = SQL_SUCCESS_WITH_INFO;
-			CC_set_error(conn, CONN_TRUNCATED, "The buffer was too small for the ConnStrOut.");
+				for (clen = strlen(szConnStrOut) - 1; clen >= 0 && szConnStrOut[clen] != ';'; clen--)
+					szConnStrOut[clen] = '\0';
+				result = SQL_SUCCESS_WITH_INFO;
+				CC_set_error(conn, CONN_TRUNCATED, "The buffer was too small for the ConnStrOut.");
+			}
 		}
 	}
 
