@@ -17,15 +17,19 @@
 #include <stdio.h>
 #include <stdarg.h>
 #include <string.h>
+#include <ctype.h>
 
 #ifndef WIN32
 #include <pwd.h>
 #include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
 #include <unistd.h>
 #else
 #include <process.h>			/* Byron: is this where Windows keeps def.
 								 * of getpid ? */
 #endif
+
 #include "connection.h"
 #include "multibyte.h"
 
@@ -117,6 +121,10 @@ mylog(char *fmt,...)
 	va_list		args;
 	char		filebuf[80];
 
+#ifndef WIN32
+	int		filedes=0;
+#endif
+
 	ENTER_MYLOG_CS;
 	if (mylog_on)
 	{
@@ -125,7 +133,12 @@ mylog(char *fmt,...)
 		if (!LOGFP)
 		{
 			generate_filename(MYLOGDIR, MYLOGFILE, filebuf);
+#ifdef WIN32
 			LOGFP = fopen(filebuf, PG_BINARY_A);
+#else
+			filedes = open(filebuf, O_WRONLY | O_APPEND | O_CREAT, S_IWUSR | S_IRUSR);
+			LOGFP = fdopen(filedes, PG_BINARY_A);
+#endif
 			setbuf(LOGFP, NULL);
 		}
 
@@ -162,6 +175,10 @@ qlog(char *fmt,...)
 	char		filebuf[80];
 	static FILE *LOGFP = NULL;
 
+#ifndef WIN32
+        int             filedes=0;
+#endif
+
 	ENTER_QLOG_CS;
 	if (qlog_on)
 	{
@@ -170,7 +187,12 @@ qlog(char *fmt,...)
 		if (!LOGFP)
 		{
 			generate_filename(QLOGDIR, QLOGFILE, filebuf);
-			LOGFP = fopen(filebuf, PG_BINARY_A);
+#ifdef WIN32
+                        LOGFP = fopen(filebuf, PG_BINARY_A);
+#else
+                        filedes = open(filebuf, O_WRONLY | O_APPEND | O_CREAT, S_IWUSR | S_IRUSR);
+                        LOGFP = fdopen(filedes, PG_BINARY_A);
+#endif
 			setbuf(LOGFP, NULL);
 		}
 
@@ -325,7 +347,7 @@ make_lstring_ifneeded(ConnectionClass *conn, const char *s, int len, BOOL ifallu
 					str = NULL;
 				}
 				break;
-			} 
+			}
 			if (tolower(*ptr) != *ptr)
 			{
 				if (!str)
@@ -441,3 +463,20 @@ schema_strcat1(char *buf, const char *fmt, const char *s1, const char *s, int le
 	}
 	return my_strcat1(buf, fmt, s1, s, len);
 }
+
+int 
+contains_token(char *data, char *token)
+{
+	int	i, tlen, dlen;
+
+	dlen = strlen(data);
+	tlen = strlen(token);
+
+	for (i = 0; i < dlen-tlen+1; i++)
+	{
+		if (!strnicmp((const char *)data+i, token, tlen))
+			return 1;
+	}
+
+	return 0;
+}
